@@ -35,6 +35,7 @@ import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
 import java.net.URL;
+import java.nio.file.Files;
 import java.text.ParseException;
 import java.text.SimpleDateFormat;
 import java.util.*;
@@ -127,6 +128,9 @@ public abstract class LocalPDBDirectory implements StructureIOFile {
 
 	protected static final String lineSplit = System.getProperty("file.separator");
 
+	/** Minimum size for a valid structure file (CIF or PDB), in bytes */
+	public static final long MIN_PDB_FILE_SIZE = 40;  // Empty gzip files are 20bytes. Add a few more for buffer.
+
 	private File path;
 	private List<String> extensions;
 
@@ -402,8 +406,9 @@ public abstract class LocalPDBDirectory implements StructureIOFile {
 	 * Attempts to delete all versions of a structure from the local directory.
 	 * @param pdbId
 	 * @return True if one or more files were deleted
+	 * @throws IOException if the file cannot be deleted
 	 */
-	public boolean deleteStructure(String pdbId){
+	public boolean deleteStructure(String pdbId) throws IOException{
 		boolean deleted = false;
 		// Force getLocalFile to check in obsolete locations
 		ObsoleteBehavior obsolete = getObsoleteBehavior();
@@ -421,7 +426,7 @@ public abstract class LocalPDBDirectory implements StructureIOFile {
 				// delete file
 				boolean success = existing.delete();
 				if(success) {
-					logger.info("Deleting "+existing.getAbsolutePath());
+					logger.debug("Deleting "+existing.getAbsolutePath());
 				}
 				deleted = deleted || success;
 
@@ -430,7 +435,7 @@ public abstract class LocalPDBDirectory implements StructureIOFile {
 				if(parent != null) {
 					success = parent.delete();
 					if(success) {
-						logger.info("Deleting "+parent.getAbsolutePath());
+						logger.debug("Deleting "+parent.getAbsolutePath());
 					}
 				}
 
@@ -660,8 +665,9 @@ public abstract class LocalPDBDirectory implements StructureIOFile {
 	 * Searches for previously downloaded files
 	 * @param pdbId
 	 * @return A file pointing to the existing file, or null if not found
+	 * @throws IOException If the file exists but is empty and can't be deleted
 	 */
-	public File getLocalFile(String pdbId) {
+	public File getLocalFile(String pdbId) throws IOException {
 
 		// Search for existing files
 
@@ -687,6 +693,11 @@ public abstract class LocalPDBDirectory implements StructureIOFile {
 				for(String ex : getExtensions() ){
 					File f = new File(searchdir,prefix + pdbId.toLowerCase() + ex) ;
 					if ( f.exists()) {
+						// delete files that are too short to have contents
+						if( f.length() < MIN_PDB_FILE_SIZE ) {
+							Files.delete(f.toPath());
+							return null;
+						}
 						return f;
 					}
 				}
@@ -697,9 +708,11 @@ public abstract class LocalPDBDirectory implements StructureIOFile {
 	}
 
 	protected boolean checkFileExists(String pdbId){
-		File path =  getLocalFile(pdbId);
-		if ( path != null)
-			return true;
+		try {
+			File path =  getLocalFile(pdbId);
+			if ( path != null)
+				return true;
+		} catch(IOException e) {}
 		return false;
 	}
 
